@@ -1,10 +1,58 @@
-__all__ = ["ApplicationScope", "Version"]
+__all__ = ["ApplicationScope", "CommonContext", "EdgeEdition", "Version"]
 
 import re
-from typing import Any, Optional, Tuple, Union
+from typing import Any, Iterable, List, Optional, Tuple, Union
 
+from com.google.common.eventbus import EventBus
+from com.inductiveautomation.ignition.common.expressions import FunctionFactory
+from com.inductiveautomation.ignition.common.licensing import LicenseState
+from com.inductiveautomation.ignition.common.logging import LogFilterSettings
+from com.inductiveautomation.ignition.common.script import ScriptManager
+from com.inductiveautomation.ignition.common.tags.model import TagManager
+from com.inductiveautomation.ignition.common.xmlserialization.deserialization import (
+    XMLDeserializer,
+)
+from dev.thecesrom.helper.types import AnyStr
 from java.io import InputStream
-from java.lang import IllegalArgumentException, Object, String
+from java.lang import Enum, IllegalArgumentException, Object, String
+
+
+class CommonContext(object):
+    def createDeserializer(self):
+        # type: () -> XMLDeserializer
+        raise NotImplementedError
+
+    def getEdgeEditions(self):
+        # type: () -> List[EdgeEdition]
+        raise NotImplementedError
+
+    def getEventBus(self):
+        # type: () -> EventBus
+        raise NotImplementedError
+
+    def getExpressionFunctionFactory(self):
+        # type: () -> FunctionFactory
+        raise NotImplementedError
+
+    def getLicenseState(self, moduleId):
+        # type: (AnyStr) -> LicenseState
+        raise NotImplementedError
+
+    def getLoggingManager(self):
+        # type: () -> LogFilterSettings
+        raise NotImplementedError
+
+    def getModule(self, id_):
+        # type: (AnyStr) -> Object
+        raise NotImplementedError
+
+    def getScriptManager(self):
+        # type: () -> ScriptManager
+        raise NotImplementedError
+
+    def getTagManager(self):
+        # type: () -> TagManager
+        raise NotImplementedError
 
 
 class ApplicationScope(Object):
@@ -21,13 +69,12 @@ class ApplicationScope(Object):
 
         Returns:
             The scope of this JVM, wherever it may be.
-
         """
         return -1
 
     @staticmethod
     def getScopePrefix():
-        # type: () -> String
+        # type: () -> AnyStr
         """Returns the current jvm's scope prefix, for use in thread
         names.
 
@@ -58,7 +105,7 @@ class ApplicationScope(Object):
 
     @staticmethod
     def parseScope(s):
-        # type: (String) -> int
+        # type: (AnyStr) -> int
         """Returns a bitmask representing application scope for strings
         like:
 
@@ -78,7 +125,7 @@ class ApplicationScope(Object):
 
     @staticmethod
     def toCode(scope):
-        # type: (int) -> String
+        # type: (int) -> AnyStr
         """Turns a scope int into the various scope codes:
 
             "C"= client
@@ -96,6 +143,23 @@ class ApplicationScope(Object):
         pass
 
 
+class EdgeEdition(Enum):
+    @staticmethod
+    def create(edgeFlags):
+        # type: (List[String]) -> List[EdgeEdition]
+        pass
+
+    @staticmethod
+    def getAllEditions():
+        # type: () -> List[EdgeEdition]
+        pass
+
+    @staticmethod
+    def values():
+        # type: () -> Iterable[EdgeEdition]
+        pass
+
+
 class Version(Object):
     build = 0  # type: int
     dev = True  # type: bool
@@ -108,6 +172,7 @@ class Version(Object):
 
     def __init__(self, major=0, minor=0, rev=0, build=0, beta=0, rc=0):
         # type: (int, int, int, int, int, int) -> None
+        super(Version, self).__init__()
         self.major = major
         self.minor = minor
         self.rev = rev
@@ -183,14 +248,14 @@ class Version(Object):
         return self.dev
 
     def isFutureVersion(self, arg):
-        # type: (Union[Version, String]) -> bool
+        # type: (Union[Version, AnyStr]) -> bool
         cls = type(self)
         if isinstance(arg, basestring):
             that = self.parse(arg)
         elif isinstance(arg, cls):
             that = arg
         else:
-            raise TypeError("isFutureVersion(): 1st arg can't be coerced to String.")
+            raise TypeError("isFutureVersion(): 1st arg can't be coerced to AnyStr.")
 
         return self._compare(that) == -1
 
@@ -200,7 +265,7 @@ class Version(Object):
 
     @staticmethod
     def parse(s):
-        # type: (String) -> Version
+        # type: (AnyStr) -> Version
         sem_ver = [int(i) for i in re.findall(r"-?\d+", s)]
         if len(sem_ver) < 3:
             raise IllegalArgumentException('Invalid version: "{}"'.format(s))
