@@ -1,6 +1,7 @@
 from __future__ import print_function
 
 __all__ = [
+    "DesktopManager",
     "Icon",
     "JComponent",
     "JDesktopPane",
@@ -12,7 +13,10 @@ __all__ = [
     "JPanel",
     "JPasswordField",
     "JPopupMenu",
+    "JRootPane",
     "JTextField",
+    "JToolTip",
+    "RootPaneContainer",
 ]
 
 import array
@@ -103,6 +107,36 @@ class Icon(object):
         raise NotImplementedError
 
 
+class RootPaneContainer(object):
+    def getContentPane(self):
+        # type: () -> Container
+        raise NotImplementedError
+
+    def getGlassPane(self):
+        # type: () -> Component
+        raise NotImplementedError
+
+    def getLayeredPane(self):
+        # type: () -> JLayeredPane
+        raise NotImplementedError
+
+    def getRootPane(self):
+        # type: () -> JRootPane
+        raise NotImplementedError
+
+    def setContentPane(self, contentPane):
+        # type: (Container) -> None
+        raise NotImplementedError
+
+    def setGlassPane(self, glassPane):
+        # type: (Component) -> None
+        raise NotImplementedError
+
+    def setLayeredPane(self, rootPane):
+        # type: (JLayeredPane) -> None
+        raise NotImplementedError
+
+
 class JComponent(Container):
     TOOL_TIP_TEXT_KEY = None  # type: AnyStr
     UNDEFINED_CONDITION = None  # type: int
@@ -248,8 +282,9 @@ class JDesktopPane(JLayeredPane):
 
 class JOptionPane(JComponent):
     """JOptionPane makes it easy to pop up a standard dialog box that
-    prompts users for a value or informs them of something. For
-    information about using JOptionPane, see How to Make Dialogs, a
+    prompts users for a value or informs them of something.
+
+    For information about using JOptionPane, see How to Make Dialogs, a
     section in The Java Tutorial.
     """
 
@@ -368,12 +403,13 @@ class JToolTip(JComponent):
 
 class JPopupMenu(JComponent):
     """An implementation of a popup menu -- a small window that pops up
-    and displays a series of choices. A JPopupMenu is used for the menu
-    that appears when the user selects an item on the menu bar. It is
-    also used for "pull-right" menu that appears when the selects a menu
-    item that activates it. Finally, a JPopupMenu can also be used
-    anywhere else you want a menu to appear. For example, when the user
-    right-clicks in a specified area.
+    and displays a series of choices.
+
+    A JPopupMenu is used for the menu that appears when the user selects
+    an item on the menu bar. It is also used for "pull-right" menu that
+    appears when the selects a menu item that activates it. Finally, a
+    JPopupMenu can also be used anywhere else you want a menu to appear.
+    For example, when the user right-clicks in a specified area.
     """
 
     def __init__(self, label=None):
@@ -382,6 +418,16 @@ class JPopupMenu(JComponent):
         print(label)
 
 
+class JRootPane(JComponent):
+    """A lightweight container used behind the scenes by JFrame,
+    JDialog, JWindow, JApplet, and JInternalFrame.
+    """
+
+    def __init__(self):
+        # type: () -> None
+        super(JRootPane, self).__init__()
+
+
 class JTextField(JTextComponent):
     """JTextField is a lightweight component that allows the editing of
     a single line of text.
