@@ -1,16 +1,18 @@
+__all__ = ["JTextComponent"]
+
+from dev.thecesrom.helper.types import AnyStr
 from java.awt import Container
-from java.lang import String
 
 
 class JTextComponent(Container):
     """JTextComponent is the base class for swing text components."""
 
-    _text = "Text"  # type: String
+    _text = "Text"  # type: AnyStr
 
-    def getText(self):
-        # type: () -> String
+    def getText(self, *args):
+        # type: (*int) -> AnyStr
         return self._text
 
     def setText(self, t):
-        # type: (String) -> None
+        # type: (AnyStr) -> None
         self._text = t
