@@ -17,26 +17,32 @@ __all__ = [
     "PyInteger",
     "PyList",
     "PyMethodDescr",
+    "PyModule",
     "PyNewWrapper",
     "PyObject",
     "PySequence",
     "PySequenceList",
     "PyString",
     "PyStringMap",
+    "PySystemState",
     "PyTraceback",
     "PyTuple",
     "PyType",
+    "PyVersionInfo",
     "TraceFunction",
     "Visitproc",
 ]
 
-from typing import Any, Iterable, Iterator, List, Optional, Tuple, Union
+from typing import Any, Iterable, Iterator, List, Mapping, Optional, Tuple, Union
 
 from enum import Enum
 
-import java.util
+from dev.thecesrom.helper.types import AnyStr
 from java.io import PrintWriter
-from java.lang import Class, Object, RuntimeException, String, StringBuilder, Throwable
+from java.lang import Class, Object, RuntimeException, StringBuilder, Throwable
+from java.util import Collection
+from java.util import Iterator as JIterator
+from java.util import ListIterator, Properties
 from org.python.expose import TypeBuilder
 
 
@@ -50,6 +56,7 @@ class PyObject(Object):
 
     def __init__(self, objtype=None):
         # type: (Optional[PyType]) -> None
+        super(PyObject, self).__init__()
         print(objtype)
 
     def __abs__(self):
@@ -573,15 +580,15 @@ class PyObject(Object):
         pass
 
     def asName(self, arg):
-        # type: (Union[int, PyObject]) -> String
+        # type: (Union[int, PyObject]) -> AnyStr
         pass
 
     def asString(self, index=None):
-        # type: (Optional[int]) -> String
+        # type: (Optional[int]) -> AnyStr
         pass
 
     def asStringOrNull(self, index=None):
-        # type: (Optional[int]) -> String
+        # type: (Optional[int]) -> AnyStr
         pass
 
     def bit_length(self):
@@ -665,7 +672,7 @@ class PyObject(Object):
         return True
 
     def noAttributeError(self, name):
-        # type: (String) -> None
+        # type: (AnyStr) -> None
         pass
 
     @staticmethod
@@ -674,7 +681,7 @@ class PyObject(Object):
         pass
 
     def readonlyAttributeError(self, name):
-        # type: (String) -> None
+        # type: (AnyStr) -> None
         pass
 
     def setDict(self, newDict):
@@ -707,7 +714,7 @@ class CodeFlag(Enum):
 
     @staticmethod
     def valueOf(name):
-        # type: (String) -> CodeFlag
+        # type: (AnyStr) -> CodeFlag
         pass
 
     @staticmethod
@@ -718,7 +725,7 @@ class CodeFlag(Enum):
 
 class CompilerFlags(Object):
     dont_imply_dedent = None  # type: bool
-    encoding = None  # type: String
+    encoding = None  # type: AnyStr
     only_ast = None  # type: bool
     PyCF_DONT_IMPLY_DEDENT = 512  # type: int
     PyCF_ONLY_AST = 1024  # type: int
@@ -727,6 +734,7 @@ class CompilerFlags(Object):
 
     def __init__(self, co_flags=None):
         # type: (Optional[int]) -> None
+        super(CompilerFlags, self).__init__()
         print(co_flags)
 
     def combine(self, flags):
@@ -748,7 +756,7 @@ class CompilerFlags(Object):
 
 
 class PyCode(PyObject):
-    co_name = None  # type: String
+    co_name = None  # type: AnyStr
 
     def call(self, *args):
         # type: (*Any) -> None
@@ -757,13 +765,13 @@ class PyCode(PyObject):
 
 class PyBaseCode(PyCode):
     co_argcount = None  # type: int
-    co_cellvars = None  # type: List[String]
-    co_filename = None  # type: String
+    co_cellvars = None  # type: List[AnyStr]
+    co_filename = None  # type: AnyStr
     co_firstlineno = None  # type: int
     co_flags = None  # type: CompilerFlags
-    co_freevars = None  # type: List[String]
+    co_freevars = None  # type: List[AnyStr]
     co_nlocals = None  # type: int
-    co_varnames = None  # type: List[String]
+    co_varnames = None  # type: List[AnyStr]
     jy_npurecell = None  # type: int
     varargs = None  # type: bool
     varkwargs = None  # type: bool
@@ -787,7 +795,7 @@ class PyBuiltinCallable(PyObject):
         pass
 
     def getDoc(self):
-        # type: () -> String
+        # type: () -> AnyStr
         pass
 
     def getModule(self):
@@ -816,7 +824,7 @@ class PyBuiltinCallable(PyObject):
             raise NotImplementedError
 
         def getName(self):
-            # type: () -> String
+            # type: () -> AnyStr
             raise NotImplementedError
 
         def unexpectedCall(self, nargs, keywords):
@@ -869,7 +877,7 @@ class PyDescriptor(PyObject, PyBuiltinCallable.Info):
         print(func)
 
     def getDoc(self):
-        # type: () -> String
+        # type: () -> AnyStr
         pass
 
     def getMaxargs(self):
@@ -881,7 +889,7 @@ class PyDescriptor(PyObject, PyBuiltinCallable.Info):
         pass
 
     def getName(self):
-        # type: () -> String
+        # type: () -> AnyStr
         pass
 
     def getObjClass(self):
@@ -904,12 +912,12 @@ class PyDescriptor(PyObject, PyBuiltinCallable.Info):
 class PyException(RuntimeException):
     traceback = None  # type: Optional[PyTraceback]
     type = None  # type: Optional[PyObject]
-    value = None  # type: Optional[Union[PyObject, String]]
+    value = None  # type: Optional[Union[PyObject, AnyStr]]
 
     def __init__(
         self,
         type_=None,  # type: Optional[PyObject]
-        value=None,  # type: Optional[Union[PyObject, String]]
+        value=None,  # type: Optional[Union[PyObject, AnyStr]]
         traceback=None,  # type: Optional[PyTraceback]
     ):
         # type: (...) -> None
@@ -924,7 +932,7 @@ class PyException(RuntimeException):
         pass
 
     def exceptionClassName(self, obj):
-        # type: (PyObject) -> String
+        # type: (PyObject) -> AnyStr
         pass
 
     def isExceptionClass(self, obj):
@@ -982,11 +990,11 @@ class PyFrame(PyObject):
         pass
 
     def delglobal(self, index):
-        # type: (String) -> None
+        # type: (AnyStr) -> None
         pass
 
     def dellocal(self, index):
-        # type: (Union[int, String]) -> None
+        # type: (Union[int, AnyStr]) -> None
         pass
 
     def delTrace(self):
@@ -1010,7 +1018,7 @@ class PyFrame(PyObject):
         pass
 
     def getglobal(self, index):
-        # type: (String) -> PyObject
+        # type: (AnyStr) -> PyObject
         pass
 
     def getLine(self):
@@ -1026,7 +1034,7 @@ class PyFrame(PyObject):
         pass
 
     def getname(self, index):
-        # type: (String) -> PyObject
+        # type: (AnyStr) -> PyObject
         pass
 
     def getTrace(self):
@@ -1042,7 +1050,7 @@ class PyFrame(PyObject):
         pass
 
     def setglobal(self, index, value):
-        # type: (String, PyObject) -> None
+        # type: (AnyStr, PyObject) -> None
         pass
 
     def setline(self, line):
@@ -1050,7 +1058,7 @@ class PyFrame(PyObject):
         pass
 
     def setlocal(self, index, value):
-        # type: (Union[int, String], PyObject) -> None
+        # type: (Union[int, AnyStr], PyObject) -> None
         pass
 
     def setTrace(self, trace):
@@ -1129,7 +1137,7 @@ class PySequenceList(PySequence):
         raise NotImplementedError
 
     def containsAll(self, c):
-        # type: (java.util.Collection) -> bool
+        # type: (Collection) -> bool
         raise NotImplementedError
 
     def get(self, index):
@@ -1149,7 +1157,7 @@ class PySequenceList(PySequence):
         raise NotImplementedError
 
     def iterator(self):
-        # type: () -> java.util.Iterator
+        # type: () -> JIterator
         raise NotImplementedError
 
     def lastIndexOf(self, o):
@@ -1157,7 +1165,7 @@ class PySequenceList(PySequence):
         raise NotImplementedError
 
     def listIterator(self, index=None):
-        # type: (Optional[int]) -> java.util.ListIterator
+        # type: (Optional[int]) -> ListIterator
         raise NotImplementedError
 
     def pyadd(self, *args):
@@ -1181,11 +1189,11 @@ class PySequenceList(PySequence):
         raise NotImplementedError
 
     def removeAll(self, c):
-        # type: (java.util.Collection) -> bool
+        # type: (Collection) -> bool
         raise NotImplementedError
 
     def retainAll(self, c):
-        # type: (java.util.Collection) -> bool
+        # type: (Collection) -> bool
         raise NotImplementedError
 
     def set(self, index, element):
@@ -1236,7 +1244,7 @@ class PyList(PySequenceList):
         return True
 
     def containsAll(self, c):
-        # type: (java.util.Collection) -> bool
+        # type: (Collection) -> bool
         return True
 
     def count(self, o):
@@ -1277,7 +1285,7 @@ class PyList(PySequenceList):
         return True
 
     def iterator(self):
-        # type: () -> java.util.Iterator
+        # type: () -> JIterator
         pass
 
     def lastIndexOf(self, o):
@@ -1285,7 +1293,7 @@ class PyList(PySequenceList):
         pass
 
     def listIterator(self, index=None):
-        # type: (Optional[int]) -> java.util.ListIterator
+        # type: (Optional[int]) -> ListIterator
         pass
 
     def pyadd(self, *args):
@@ -1305,11 +1313,11 @@ class PyList(PySequenceList):
         pass
 
     def removeAll(self, c):
-        # type: (java.util.Collection) -> bool
+        # type: (Collection) -> bool
         return True
 
     def retainAll(self, c):
-        # type: (java.util.Collection) -> bool
+        # type: (Collection) -> bool
         return True
 
     def reverse(self):
@@ -1337,6 +1345,10 @@ class PyList(PySequenceList):
         pass
 
 
+class PyModule(PyObject):
+    pass
+
+
 class PyString(PyObject):
     def __init__(self, *args):
         # type: (*Any) -> None
@@ -1344,6 +1356,183 @@ class PyString(PyObject):
         super(PyString, self).__init__()
 
 
+class PySystemState(PyObject):
+    def argv(self):
+        # type: () -> PyList
+        pass
+
+    @staticmethod
+    def builtin_module_names():
+        # type: () -> PyTuple
+        pass
+
+    def builtins(self):
+        # type: () -> PyObject
+        pass
+
+    @staticmethod
+    def byteorder():
+        # type: () -> PyString
+        pass
+
+    @staticmethod
+    def copyright():
+        # type: () -> PyObject
+        pass
+
+    def dont_write_bytecode(self):
+        # type: () -> bool
+        pass
+
+    @staticmethod
+    def exec_prefix():
+        # type: () -> PyObject
+        pass
+
+    def executable(self):
+        # type: () -> PyObject
+        pass
+
+    @staticmethod
+    def flags():
+        # type: () -> Class
+        pass
+
+    @staticmethod
+    def float_info():
+        # type: () -> PyObject
+        pass
+
+    @staticmethod
+    def float_repr_style():
+        # type: () -> PyString
+        pass
+
+    @staticmethod
+    def hexversion():
+        # type: () -> int
+        pass
+
+    def last_traceback(self):
+        # type: () -> PyObject
+        pass
+
+    def last_type(self):
+        # type: () -> PyObject
+        pass
+
+    def last_value(self):
+        # type: () -> PyObject
+        pass
+
+    @staticmethod
+    def long_info():
+        # type: () -> PyObject
+        pass
+
+    @staticmethod
+    def maxint():
+        # type: () -> int
+        pass
+
+    @staticmethod
+    def maxsize():
+        # type: () -> int
+        pass
+
+    @staticmethod
+    def maxunicode():
+        # type: () -> int
+        pass
+
+    def meta_path(self):
+        # type: () -> PyList
+        pass
+
+    @staticmethod
+    def minint():
+        # type: () -> int
+        pass
+
+    def modules(self):
+        # type: () -> PyObject
+        pass
+
+    def modules_reloading(self):
+        # type: () -> Mapping[AnyStr, PyModule]
+        pass
+
+    def path(self):
+        # type: () -> PyList
+        pass
+
+    def path_hooks(self):
+        # type: () -> PyList
+        pass
+
+    def path_importer_cache(self):
+        # type: () -> PyObject
+        pass
+
+    def platform(self):
+        # type: () -> PyObject
+        pass
+
+    @staticmethod
+    def prefix():
+        # type: () -> PyObject
+        pass
+
+    def ps1(self):
+        # type: () -> PyObject
+        pass
+
+    def ps2(self):
+        # type: () -> PyObject
+        pass
+
+    @staticmethod
+    def py3kwarning():
+        # type: () -> bool
+        pass
+
+    @staticmethod
+    def registry():
+        # type: () -> Properties
+        pass
+
+    def stderr(self):
+        # type: () -> PyObject
+        pass
+
+    def stdin(self):
+        # type: () -> PyObject
+        pass
+
+    def stdout(self):
+        # type: () -> PyObject
+        pass
+
+    @staticmethod
+    def subversion():
+        # type: () -> PyTuple
+        pass
+
+    @staticmethod
+    def version():
+        # type: () -> PyString
+        pass
+
+    @staticmethod
+    def version_info():
+        # type: () -> PyVersionInfo
+        pass
+
+    def warnoptions(self):
+        # type: () -> PyList
+        pass
+
+
 class PyTraceback(PyObject):
     tb_frame = None  # type: PyFrame
     tb_lineno = None  # type: int
@@ -1355,7 +1544,7 @@ class PyTraceback(PyObject):
         print(next, frame)
 
     def dumpStack(self, buf=None):
-        # type: (Optional[StringBuilder]) -> Optional[String]
+        # type: (Optional[StringBuilder]) -> Optional[AnyStr]
         pass
 
     def refersDirectlyTo(self, ob):
@@ -1390,7 +1579,7 @@ class PyTuple(PySequenceList):
         return True
 
     def containsAll(self, c):
-        # type: (java.util.Collection) -> bool
+        # type: (Collection) -> bool
         return True
 
     def count(self, value):
@@ -1423,7 +1612,7 @@ class PyTuple(PySequenceList):
         return True
 
     def iterator(self):
-        # type: () -> java.util.Iterator
+        # type: () -> JIterator
         pass
 
     def lastIndexOf(self, o):
@@ -1431,7 +1620,7 @@ class PyTuple(PySequenceList):
         pass
 
     def listIterator(self, index=None):
-        # type: (Optional[int]) -> java.util.ListIterator
+        # type: (Optional[int]) -> ListIterator
         pass
 
     def pyadd(self, *args):
@@ -1451,11 +1640,11 @@ class PyTuple(PySequenceList):
         pass
 
     def removeAll(self, c):
-        # type: (java.util.Collection) -> bool
+        # type: (Collection) -> bool
         return True
 
     def retainAll(self, c):
-        # type: (java.util.Collection) -> bool
+        # type: (Collection) -> bool
         return True
 
     def set(self, index, element):
@@ -1490,7 +1679,7 @@ class PyType(PyObject):
         pass
 
     def compatibleForAssignment(self, other, attribute):
-        # type: (PyType, String) -> None
+        # type: (PyType, AnyStr) -> None
         pass
 
     def delBases(self):
@@ -1517,7 +1706,7 @@ class PyType(PyObject):
         pass
 
     def fastGetName(self):
-        # type: () -> String
+        # type: () -> AnyStr
         pass
 
     @staticmethod
@@ -1554,7 +1743,7 @@ class PyType(PyObject):
         pass
 
     def getName(self):
-        # type: () -> String
+        # type: () -> AnyStr
         pass
 
     def getNumSlots(self):
@@ -1578,11 +1767,11 @@ class PyType(PyObject):
         return True
 
     def lookup_where(self, name, where):
-        # type: (String, List[PyObject]) -> PyObject
+        # type: (AnyStr, List[PyObject]) -> PyObject
         pass
 
     def lookup(self, name):
-        # type: (String) -> PyObject
+        # type: (AnyStr) -> PyObject
         pass
 
     def needsFinalizer(self):
@@ -1593,7 +1782,7 @@ class PyType(PyObject):
     def newType(
         new_,  # type: PyNewWrapper
         metatype,  # type: PyType
-        name,  # type: String
+        name,  # type: AnyStr
         bases,  # type: Tuple[Any, ...]
         dict_,  # type: PyObject
     ):
@@ -1629,11 +1818,11 @@ class PyType(PyObject):
         pass
 
     def setName(self, name):
-        # type: (String) -> None
+        # type: (AnyStr) -> None
         pass
 
     def super_lookup(self, ref, name):
-        # type: (PyType, String) -> PyObject
+        # type: (PyType, AnyStr) -> PyObject
         pass
 
     def traverse(self, visit, arg):
@@ -1695,6 +1884,10 @@ class TraceFunction(Object):
         raise NotImplementedError
 
 
+class PyVersionInfo(PyTuple):
+    pass
+
+
 class Visitproc(object):
     def visit(self, obj, arg):
         # type: (PyObject, Object) -> int
